#+title: Readme

# Getting started  
1. `pip install pyscreenshotter`  
2. In a terminal run the cmd: `pyscreenshotter`  
3. Press 's' or 'q' to capture/quit respectively.  

## Changing Keybinds  
1. You can change the keybinds by passing two cmdline arguments like so:  
   ~pyscreenshotter j k~  

   I.e. make j = capture, and k = quit  
